@@ -1,7 +1,7 @@
 /*
  * aurora - Communications with Magnetek Aurora Inverter
  *
- * Copyright (C) 2006-2010 Curtis J. Blank curt@curtronics.com
+ * Copyright (C) 2006-2015 Curtis J. Blank curt@curtronics.com
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -22,12 +22,12 @@
  * Staring with v1.5-0 this work based on Power One's 'Aurora Inverter
  * Series - Communication Protocol -' document, Rel. 4.6 25/02/09
  *
- * Special thanks to Tron Melzl at Magnetek for all his help including,
- * but not limited to, supplying the Communications Protocol document
+ * Special thanks to Tron Melzl at Magnetek for all his help including, but
+ * by no means limited to, supplying the Communications Protocol document
  *
  */
 
-#define	VersionMH	"1.7.2"
+#define	VersionMH	"1.8.7"
 
 #ifndef __MAIN_H__
 #define __MAIN_H__
@@ -41,6 +41,7 @@
 typedef int BOOL;		/* yet another bool definition */
 #define TRUE 1
 #define FALSE 0
+#define _ERROR_ -999999999
 
 typedef unsigned char BYTE;
 typedef unsigned short WORD;
@@ -63,7 +64,9 @@ extern BOOL bColOutput;
 extern BOOL bCalcGridPwr;
 extern BOOL bRptReties;
 extern BOOL bRptReadPause;
-extern char RunTime[18];
+extern BOOL bSwapEndian;
+extern BOOL bUseMultiplierQ;
+extern float yMultiplierK;
 extern float yCost;
 extern char *sCostType;
 extern int yTimeout;
@@ -71,18 +74,25 @@ extern long unsigned int PID;
 extern int yMaxAttempts;
 extern int yReadPause;
 extern long int yCommPause;
+extern unsigned char yDelay;
+extern time_t startTimeValue;
+extern int yGetCount;
+extern int yCentral;
+extern int yMaxRunTime;
 extern int yCheckSetTime;
 extern struct timeval lastcommtv;
 
 extern FILE *outfp;
 
-extern int ModelID;
-
+extern char* getCurTime();
 extern int ClrSerLock(long unsigned int PID);
 extern int RestorePort(int fdser);
 
 #define	ttyLCKloc	"/var/lock/LCK.."	/* location and prefix of serial port lock file */
 
+/* macros */
+#define MAX(a,b) ({ typeof (a) _a = (a); typeof (b) _b = (b); _a > _b ? _a : _b; })
+
 /* command structure */
 #define	cAddress	0
 #define	cCommand	1
@@ -90,8 +100,10 @@ extern int RestorePort(int fdser);
 #define	cParam1		2
 #define cParam1End	3
 #define	cParam2		3
+#define cParam2End	4
 #define	cParam3		4
 #define	cParam4		5
+#define cParam4End	6
 #define	cParam5		6
 #define	cParam6		7
 #define cCRC_L		8
